==> monthofswords-common-1.21.0-sources.jar: com/samsthenerd/monthofswords/items/IceSwordItem.java <==
package com.samsthenerd.monthofswords.items;

import com.samsthenerd.monthofswords.SwordsMod;
import com.samsthenerd.monthofswords.utils.BFSHelper;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1322;
import net.minecraft.class_1657;
import net.minecraft.class_1680;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1829;
import net.minecraft.class_1832;
import net.minecraft.class_1856;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_243;
import net.minecraft.class_2583;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3481;
import net.minecraft.class_3966;
import net.minecraft.class_5134;
import net.minecraft.class_5819;
import net.minecraft.class_9274;
import net.minecraft.item.*;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.UnaryOperator;

public class IceSwordItem extends SwordtemberItem implements SwordActionHaverServer{

    public static final class_1832 ICE_MATERIAL = new ClassyToolMaterial(1000, 7.5f, 1.5f,
        class_3481.field_49926, 20, () -> class_1856.method_8091(class_1802.field_8178));

    public static final class_2960 ICE_SWORD_NO_BURN_MODIFIER = SwordsMod.id("iceswordnoburn");

    // TODO: make this data driven maybe?
    private static final Map<class_2248, class_2680> FREEZE_MAP = new HashMap<>();

    static {
        FREEZE_MAP.put(class_2246.field_10382, class_2246.field_10110.method_9564());
        FREEZE_MAP.put(class_2246.field_10110, class_2246.field_10295.method_9564());
        FREEZE_MAP.put(class_2246.field_10295, class_2246.field_10225.method_9564());
        FREEZE_MAP.put(class_2246.field_10225, class_2246.field_10384.method_9564());
        FREEZE_MAP.put(class_2246.field_10164, class_2246.field_10540.method_9564());
    }

    public IceSwordItem(class_1792.class_1793 itemSettings) {
        super(ICE_MATERIAL, itemSettings.method_57348(
            class_1829.method_57394(ICE_MATERIAL, 3, -2.4f)
                .method_57484(
                    class_5134.field_51579,
                    new class_1322(ICE_SWORD_NO_BURN_MODIFIER, -10.0, class_1322.class_1323.field_6328),
                    class_9274.field_49217
            ))
        );
    }

    @Override
    public float method_58403(class_1297 target, float baseAttackDamage, class_1282 damageSource) {
        if(damageSource.method_5529() instanceof class_1309 attacker){
            return attacker.method_32314() ? 1f : 0;
        }
        return 0;
    }

    @Override
    public boolean method_7873(class_1799 stack, class_1309 target, class_1309 attacker) {
        class_1937 world = attacker.method_37908();
        class_5819 random = world.method_8409();
        world.method_8396(null, attacker.method_24515(), class_3417.field_15081, class_3419.field_15248, 0.5f, (random.method_43057() - random.method_43057()) * 0.2f + 2f);
        target.method_32319(true);
        // 1 damage every 40 ticks (2 seconds) when frozen
        // entities take damage when freezeTicks >= 140
        // when not actively freezing, freezeTicks go down 2 ft per tick.
        // ((totalFreeze - 140)/2)/40 == amount of damage-ish
        // totalFreeze ~= damage * 80 + 140
        // fair to take like, 3 damage from it? - note that isn't per hit, necessarily. like it won't stack between quick consecutive hits
        target.method_32317(Math.max(380, target.method_32312()));
        return super.method_7873(stack, target, attacker);
    }

    @Override
    public class_1271<class_1799> method_7836(class_1937 world, class_1657 player, class_1268 hand) {
        class_1799 stack = player.method_5998(hand);
        class_5819 random = world.method_8409();
        if(!player.method_7357().method_7904(this)){
            class_1680 snowball = new class_1680(player.method_37908(), player){
                @Override
                protected void method_7454(class_3966 entityHitResult) {
                    super.method_7454(entityHitResult);
                    class_1297 entity = entityHitResult.method_17782();
                    entity.method_32319(true);
                    entity.method_32317(Math.max(250, entity.method_32312()));
                }
            };
            snowball.method_18799(player.method_5720().method_1021(1.5f));
            class_243 lookVec = player.method_5720();
            snowball.method_33574(player.method_19538().method_1031(lookVec.field_1352, 1.4, lookVec.field_1350));
            player.method_37908().method_8649(snowball);
            player.method_7357().method_7906(this, 30);
            stack.method_7970(1, player, hand == class_1268.field_5808 ? class_1304.field_6173 : class_1304.field_6171);
            world.method_8396(null, player.method_24515(), class_3417.field_27851, class_3419.field_15245, 2f, (random.method_43057() - random.method_43057()) * 0.2f + 1.0f);
            return class_1271.method_22427(stack);
        }
        return class_1271.method_22430(stack);
    }

    @Override
    public boolean doSwordAction(class_1657 player, class_1799 swordStack){

        if(player.method_7357().method_7904(this)) return false;

        class_1937 world = player.method_37908();
        class_243 lookVec = player.method_5720();

        class_5819 random = world.method_8409();
        List<class_1297> nearbyEnts = world.method_8335(player, new class_238(player.method_24515()).method_1014(6));

        for(class_1297 target : nearbyEnts){
            target.method_32319(true);
            target.method_32317(Math.max(460, target.method_32312()));
            world.method_8396(null, player.method_24515(), class_3417.field_27847, class_3419.field_15248, 2.0f, (random.method_43057() - random.method_43057()) * 0.2f + 1.0f);
        }

        Map<class_2338, Integer> iceZone = BFSHelper.runBFS(world, player.method_24515(),
            (worldArg, pos, dist) -> {
                class_2248 block = worldArg.method_8320(pos).method_26204();
                return dist < 2 || FREEZE_MAP.containsKey(block);
            }, 4, true);

        for(class_2338 fPos : iceZone.keySet()){
            class_2248 fBlock = world.method_8320(fPos).method_26204();
            class_2680 newState = FREEZE_MAP.get(fBlock);
            if(newState != null){
                world.method_8501(fPos, newState);
            }
        }

        player.method_7357().method_7906(this, 50 + Math.min(nearbyEnts.size() * 20, 300));
        world.method_8396(null, player.method_24515(), class_3417.field_27850, class_3419.field_15248, 1.0f, (random.method_43057() - random.method_43057()) * 0.2f + 1.0f);
        swordStack.method_7970(3 + Math.min(nearbyEnts.size() * 2, 12), player, player.method_6047() == swordStack ? class_1304.field_6173 : class_1304.field_6171);
        return true;
    }

    @Override
    public UnaryOperator<class_2583> getSwordTooltipStyleModifier(){
        return (style) -> style.method_36139(0x5eefff);
    }
}

==> monthofswords-common-1.30.1-sources.jar: com/samsthenerd/monthofswords/items/IceSwordItem.java <==
package com.samsthenerd.monthofswords.items;

import com.samsthenerd.monthofswords.SwordsMod;
import com.samsthenerd.monthofswords.utils.BFSHelper;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1322;
import net.minecraft.class_1657;
import net.minecraft.class_1680;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1829;
import net.minecraft.class_1832;
import net.minecraft.class_1856;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_243;
import net.minecraft.class_2583;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3481;
import net.minecraft.class_3966;
import net.minecraft.class_5134;
import net.minecraft.class_5819;
import net.minecraft.class_9274;
import net.minecraft.item.*;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.UnaryOperator;

public class IceSwordItem extends SwordtemberItem implements SwordActionHaverServer{

    public static final class_1832 ICE_MATERIAL = new ClassyToolMaterial(1000, 7.5f, 1.5f,
        class_3481.field_49926, 20, () -> class_1856.method_8091(class_1802.field_8178));

    public static final class_2960 ICE_SWORD_NO_BURN_MODIFIER = SwordsMod.id("iceswordnoburn");

    // TODO: make this data driven maybe?
    private static final Map<class_2248, class_2680> FREEZE_MAP = new HashMap<>();

    static {
        FREEZE_MAP.put(class_2246.field_10382, class_2246.field_10110.method_9564());
        FREEZE_MAP.put(class_2246.field_10110, class_2246.field_10295.method_9564());
        FREEZE_MAP.put(class_2246.field_10295, class_2246.field_10225.method_9564());
        FREEZE_MAP.put(class_2246.field_10225, class_2246.field_10384.method_9564());
        FREEZE_MAP.put(class_2246.field_10164, class_2246.field_10540.method_9564());
    }

    public IceSwordItem(class_1792.class_1793 itemSettings) {
        super(ICE_MATERIAL, itemSettings.method_57348(
            class_1829.method_57394(ICE_MATERIAL, 3, -2.4f)
                .method_57484(
                    class_5134.field_51579,
                    new class_1322(ICE_SWORD_NO_BURN_MODIFIER, -10.0, class_1322.class_1323.field_6328),
                    class_9274.field_49217
            ))
        );
    }

    @Override
    public float method_58403(class_1297 target, float baseAttackDamage, class_1282 damageSource) {
        if(damageSource.method_5529() instanceof class_1309 attacker){
            return attacker.method_32314() ? 1f : 0;
        }
        return 0;
    }

    @Override
    public boolean method_7873(class_1799 stack, class_1309 target, class_1309 attacker) {
        class_1937 world = attacker.method_37908();
        class_5819 random = world.method_8409();
        world.method_8396(null, attacker.method_24515(), class_3417.field_15081, class_3419.field_15248, 0.5f, (random.method_43057() - random.method_43057()) * 0.2f + 2f);
        target.method_32319(true);
        // 1 damage every 40 ticks (2 seconds) when frozen
        // entities take damage when freezeTicks >= 140
        // when not actively freezing, freezeTicks go down 2 ft per tick.
        // ((totalFreeze - 140)/2)/40 == amount of damage-ish
        // totalFreeze ~= damage * 80 + 140
        // fair to take like, 3 damage from it? - note that isn't per hit, necessarily. like it won't stack between quick consecutive hits
        target.method_32317(Math.max(380, target.method_32312()));
        return super.method_7873(stack, target, attacker);
    }

    @Override
    public class_1271<class_1799> method_7836(class_1937 world, class_1657 player, class_1268 hand) {
        class_1799 stack = player.method_5998(hand);
        class_5819 random = world.method_8409();
        if(!player.method_7357().method_7904(this)){
            class_1680 snowball = new class_1680(player.method_37908(), player){
                @Override
                protected void method_7454(class_3966 entityHitResult) {
                    super.method_7454(entityHitResult);
                    class_1297 entity = entityHitResult.method_17782();
                    entity.method_32319(true);
                    entity.method_32317(Math.max(250, entity.method_32312()));
                }
            };
            snowball.method_18799(player.method_5720().method_1021(1.5f));
            class_243 lookVec = player.method_5720();
            snowball.method_33574(player.method_19538().method_1031(lookVec.field_1352, 1.4, lookVec.field_1350));
            player.method_37908().method_8649(snowball);
            player.method_7357().method_7906(this, 30);
            stack.method_7970(1, player, hand == class_1268.field_5808 ? class_1304.field_6173 : class_1304.field_6171);
            world.method_8396(null, player.method_24515(), class_3417.field_27851, class_3419.field_15245, 2f, (random.method_43057() - random.method_43057()) * 0.2f + 1.0f);
            return class_1271.method_22427(stack);
        }
        return class_1271.method_22430(stack);
    }

    @Override
    public boolean doSwordAction(class_1657 player, class_1799 swordStack){

        if(player.method_7357().method_7904(this)) return false;

        boolean canBeDestructive = SwordsMod.canBeDestructive(player, null);

        class_1937 world = player.method_37908();
        class_243 lookVec = player.method_5720();

        class_5819 random = world.method_8409();
        List<class_1297> nearbyEnts = world.method_8335(player, new class_238(player.method_24515()).method_1014(6));

        for(class_1297 target : nearbyEnts){
            target.method_32319(true);
            target.method_32317(Math.max(460, target.method_32312()));
            world.method_8396(null, player.method_24515(), class_3417.field_27847, class_3419.field_15248, 2.0f, (random.method_43057() - random.method_43057()) * 0.2f + 1.0f);
        }

        int numFrozen = 0;
        if(canBeDestructive) {
            Map<class_2338, Integer> iceZone = BFSHelper.runBFS(world, player.method_24515(),
                (worldArg, pos, dist) -> {
                    class_2248 block = worldArg.method_8320(pos).method_26204();
                    return dist < 2 || FREEZE_MAP.containsKey(block);
                }, 4, true);

            numFrozen = iceZone.keySet().size();
            for (class_2338 fPos : iceZone.keySet()) {
                class_2248 fBlock = world.method_8320(fPos).method_26204();
                class_2680 newState = FREEZE_MAP.get(fBlock);
                if (newState != null) {
                    world.method_8501(fPos, newState);
                }
            }
        }

        player.method_7357().method_7906(this, Math.min(numFrozen, 80) + Math.min(nearbyEnts.size() * 20, 300));
        world.method_8396(null, player.method_24515(), class_3417.field_27850, class_3419.field_15248, 1.0f, (random.method_43057() - random.method_43057()) * 0.2f + 1.0f);
        swordStack.method_7970(3 + Math.min(nearbyEnts.size() * 2, 12), player, player.method_6047() == swordStack ? class_1304.field_6173 : class_1304.field_6171);
        return true;
    }

    @Override
    public UnaryOperator<class_2583> getSwordTooltipStyleModifier(){
        return (style) -> style.method_36139(0x5eefff);
    }
}
